@@ -3,60 +3,46 @@ BEGIN {
   $Installer::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Installer::VERSION = '0.001';
+  $Installer::VERSION = '0.002';
 }
 # ABSTRACT: What does it do? It installs stuff....
 
 use strict;
 use warnings;
-use Exporter 'import';
-
 use Installer::Target;
 
-our @EXPORT = qw(
-
-  install_to
+our @functions = qw(
 
   run
   url
   file
   perl
   cpanm
+  pip
 
 );
 
-sub install_to {
-  my ( $target_directory, $installer_code ) = @_;
-  my $installer_target = Installer::Target->new(
-    target_directory => $target_directory,
-    installer_code => $installer_code,
-  );
-  $installer_target->installation;
-}
-
-sub run {
-  die "Not inside installation" unless defined $Installer::Target::current;
-  $Installer::Target::current->custom_run(@_);
-}
-
-sub url {
-  die "Not inside installation" unless defined $Installer::Target::current;
-  $Installer::Target::current->install_url(@_);
-}
-
-sub file {
-  die "Not inside installation" unless defined $Installer::Target::current;
-  $Installer::Target::current->install_file(@_);
-}
-
-sub perl {
-  die "Not inside installation" unless defined $Installer::Target::current;
-  $Installer::Target::current->install_perl(@_);
-}
-
-sub cpanm {
-  die "Not inside installation" unless defined $Installer::Target::current;
-  $Installer::Target::current->install_cpanm(@_);
+sub import {
+  my $pkg = caller;
+  {
+    no strict 'refs';
+    *{"$pkg\::install_to"} = sub {
+      my ( $target_directory, $installer_code ) = @_;
+      my $installer_target = Installer::Target->new(
+        target_directory => $target_directory,
+        installer_code => $installer_code,
+      );
+      $installer_target->installation;
+    };
+  }
+  for my $command (@functions) {
+    my $function = 'install_'.$command;
+    no strict 'refs';
+    *{"$pkg\::$command"} = sub {
+      die "Not inside installation" unless defined $Installer::Target::current;
+      $Installer::Target::current->$function(@_);
+    };
+  }
 }
 
 1;
@@ -71,12 +57,10 @@ Installer - What does it do? It installs stuff....
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
-  use strict;
-  use warnings;
   use Installer;
 
   install_to $ENV{HOME}.'/myenv' => sub {
@@ -92,11 +76,29 @@ version 0.001
     cpanm "DBD::Pg";
   };
 
+Or in class usage (not suggested):
+
+  use Installer::Target;
+
+  my $target = Installer::Target->new(
+    target_directory => $ENV{HOME}.'/myenv',
+  );
+
+  $target->prepare_installation;
+  $target->install_perl("5.18.1");
+  $target->install_file("postgresql-9.2.4.tar.gz", with => {
+    pgport => 15432,
+  });
+  $target->install_cpanm("DBD::Pg","Plack");
+  # will run in the target directory
+  $target->install_run("command","--with-args");
+  $target->finish_installation;
+
 =head1 DESCRIPTION
 
-See L<installer> for more information
+See L<installer> for more information.
 
-B<TOTALLY ALPHA, YOU NEVER SAW THIS!!! GO AWAY!!!>
+B<TOTALLY BETA, PLEASE TEST :D>
 
 =encoding utf8
 
